// $Id: person.h,v 1.2 2017/04/10 00:29:35 leavens Exp leavens $
#ifndef PERSON_H
#define PERSON_H 1
#include <stdlib.h>
#include <stdbool.h>
#define MAX_NAME_LENGTH 50
// The following is for use in scanf calls
#define NAME_READING_FORMAT "%50s"

typedef struct person_s {
    const char *first_name;
    const char *last_name;
} person_t;

// Make "person" a synonym for a person_t pointer type.
typedef person_t *person;

// requires: first_name and last_name are both null-terminated
//           strings that are allocated on the heap.
// effect: creates a fresh person_t object allocated on the heap,
//         initializes its fields with the corresponding arguments,
//         and returns a pointer to the new object
//         (or NULL if the new object cannot be allocated)
//         When malloc fails the message "malloc failed!" is printed on stdout.
extern person make_person(const char *first_name, const char *last_name);

// requires: stdin and stdout are open; fn_prompt, ln_prompt are
//           all allocated, null-terminated strings.
// modifies: stdin, stdout
// effect: prompts with fn_prompt on stdout, then reads the first name.
//         Then prompts with ln_prompt on stdout and reads the last name.
//         Names are assumed to be no more than MAX_NAME_LENGTH chars long.
//         Then allocates a person_t struct on the heap and initializes it
//         with the data read from stdin, and returns a pointer to that
//         newly allocated struct (or NULL if there was an error).
//         When malloc fails the message "malloc failed!" is printed on stdout.
extern person read_person(const char *fn_prompt, const char* ln_prompt);

// requires: p is allocated (and not NULL)
// ensures: result is the first name of p
extern const char *first_name(person p);

// requires: p is allocated (and not NULL)
// ensures: result is the last name of p
extern const char *last_name(person p);

// requires: p is allocated (and not NULL)
// ensures: result is a string of the form:
//   "Firstname Lastname"
// where Firstname is the result of calling first_name() on p,
// and Lastname is the result of calling last_name() on p.
extern char *person_to_string(person p);

// requires: p1 and p2 are both allocated (and not NULL)
// ensures: result is true just when each field of p1 is equal to
// the corresponding field of p2 (i.e., when they have the same
// first names and last names).
extern bool equal_person(person p1, person p2);
#endif
