// $Id: test_us_phone.c,v 1.3 2017/04/10 00:29:35 leavens Exp leavens $
// Compile with:
// gcc tap.c testing_io.c us_phone.c test_us_phone.c -o test_us_phone

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "tap.h"
#include "testing_io.h"
#include "us_phone.h"

static int test_read_us_phone() {
    for (int i = 0; i < 7; i++) {
	us_phone p = read_us_phone("area code (digits only): ",
				   "number (in the form 555-1212): ");
	if (p == NULL) {
	    continue;
	}
	printf("read phone %d is: \"%s\"\n", i, us_phone_to_string(p));
    }
    return EXIT_SUCCESS;
}

int main() {
    plan(19);
    us_phone pTV = make_us_phone("913", "555", "1212");
    ok(pTV != NULL);
    if (pTV != NULL) {
	ok(pTV->area[0] == 9 && pTV->area[1] == 1 && pTV->area[2] == 3,
	   "pTV->area[0] == 9 && pTV->area[1] == 1 && pTV->area[2] == 3");
	ok(pTV->exchange[0] == 5 && pTV->exchange[1] == 5 && pTV->exchange[2] == 5,
	   "pTV->exchange[0] == 5 && pTV->exchange[1] == 5 && pTV->exchange[2] == 5");
	ok(pTV->subscriber[0] == 1 && pTV->subscriber[1] == 2
	   && pTV->subscriber[2] == 1 && pTV->subscriber[3] == 2,
	   "pTV->subscriber[0] == 4 && pTV->subscriber[1] == 7\n && pTV->subscriber[2] == 5 && pTV->subscriber[3] == 2");
    }
    
    us_phone pGL = make_us_phone("407", "823", "4758");
    ok(pGL != NULL);
    if (pGL != NULL) {
	ok(pGL->area[0] == 4 && pGL->area[1] == 0 && pGL->area[2] == 7,
	   "pGL->area[0] == 4 && pGL->area[1] == 0 && pGL->area[2] == 7");
	ok(pGL->exchange[0] == 8 && pGL->exchange[1] == 2 && pGL->exchange[2] == 3,
	   "pGL->exchange[0] == 8 && pGL->exchange[1] == 2 && pGL->exchange[2] == 3");
	ok(pGL->subscriber[0] == 4 && pGL->subscriber[1] == 7
	   && pGL->subscriber[2] == 5 && pGL->subscriber[3] == 8,
	   "pGL->subscriber[0] == 4 && pGL->subscriber[1] == 7\n && pGL->subscriber[2] == 5 && pGL->subscriber[3] == 8");
    }

    if (pTV != NULL && pGL != NULL) {
	ok(strcmp(area_code(pTV), "913") == 0,
	   "strcmp(area_code(pTV), \"913\") == 0, area_code(pTV) == \"%s\"",
	   area_code(pTV));
	ok(strcmp(area_code(pGL), "407") == 0,
	   "strcmp(area_code(pGL), \"407\") == 0, area_code(pGL) == \"%s\"",
	   area_code(pGL));

	ok(strcmp(digits(pTV), "555-1212") == 0,
	   "strcmp(digits(pTV), \"555-1212\") == 0, digits(pTV) == \"%s\"",
	   digits(pTV));
	ok(strcmp(digits(pGL), "823-4758") == 0,
	   "strcmp(digits(pGL), \"823-4758\") == 0, digits(pGL) == \"%s\"", 
	   digits(pGL));

	ok(strcmp(us_phone_to_string(pTV), "(913)555-1212") == 0,
	   "us_phone_to_string(pTV) == \"%s\"", us_phone_to_string(pTV));
	ok(strcmp(us_phone_to_string(pGL), "(407)823-4758") == 0,
	   "us_phone_to_string(pGL) == \"%s\"", us_phone_to_string(pGL));

	ok(equal_us_phone(pTV, pTV), "equal_us_phone(pTV, pTV)");
	ok(equal_us_phone(pGL, pGL), "equal_us_phone(pGL, pGL)");
	ok(!equal_us_phone(pTV, pGL), "!equal_us_phone(pTV, pGL)");
	ok(!equal_us_phone(pGL, pTV), "!equal_us_phone(pGL, pTV)");
    }
    
    testproc(test_read_us_phone, "test_us_phone1");

    
    return exit_status();
}
